package de.lmu.ifi.medien.mmi2.labyrinth;

import java.io.IOException;
import java.util.Vector;

import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

import android.app.Activity;
import android.content.res.XmlResourceParser;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;



public class MainActivity extends Activity {

	Vector<Line> lines = null;
	LabyrinthView labyrinthView = null;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		// read labyrinth wall lines from /res/xml/labyrinth.xml
		try {
			lines = parseLabyrinthXml();
		} catch (Exception ex) {
			Log.d("MainActivity", "XML Parser Exception: " + ex.toString());
		}

		// debug output
		for (int i = 0; i < lines.size(); i++) {
			Log.d("MainActivity", lines.elementAt(i).toString());
		}

		// show LabyrinthView
		labyrinthView = new LabyrinthView(this, lines);
		setContentView(labyrinthView);
	}

	public Vector<Line> parseLabyrinthXml() throws IOException, XmlPullParserException {
		XmlResourceParser parser = getResources().getXml(R.xml.labyrinth);

		Vector<Line> lines = new Vector<Line>();

		parser.next();
		int eventType = parser.getEventType();

		while (eventType != XmlPullParser.END_DOCUMENT) {
			switch (eventType) { 
			case XmlPullParser.START_DOCUMENT: 
				// ignore
				break;
			case XmlPullParser.START_TAG:
				// debug output
				/*
				Log.d("MainActivity", "START_TAG " + parser.getName());
				int n = parser.getAttributeCount();
				Log.d("MainActivity", "attribute count = " + n);
				for (int i = 0; i < n; i++) {
					Log.d("MainActivity", "attribute: " + parser.getAttributeName(i) + 
							", type = " + parser.getAttributeType(i));
				}
				 */
				if ("line".equals(parser.getName())) {
					Line line = new Line();
					line.x1 = parser.getAttributeIntValue(null, "x", 0);
					line.y1 = parser.getAttributeIntValue(null, "y", 0);
					line.length = parser.getAttributeIntValue(null, "length", 0);
					String os = parser.getAttributeValue(null, "orientation").toUpperCase();
					if ("E".equals(os)) {
						line.orientation = Line.EAST;
						line.x2 = line.x1 + line.length;
						line.y2 = line.y1;
					}
					if ("N".equals(os)) {
						line.orientation = Line.NORTH;
						line.x2 = line.x1;
						line.y2 = line.y1 - line.length;
					}
					if ("W".equals(os)) {
						line.orientation = Line.WEST;
						line.x2 = line.x1 - line.length;
						line.y2 = line.y1;
					}
					if ("S".equals(os)) {
						line.orientation = Line.SOUTH;
						line.x2 = line.x1;
						line.y2 = line.y1 + line.length;
					}

					lines.add(line);

				}
				break;
			case XmlPullParser.END_TAG:
				// ignore
				break;
			case XmlPullParser.TEXT:
				// ignore
				break;
			default:
				// ignore
				break;
			}
			eventType = parser.next();
		}

		return lines;

	}
	
	// add options menu...

}
